@@ -22,6 +22,7 @@ import (
 	"crypto/rand"
 	"crypto/rsa"
 	"crypto/x509"
+	"encoding/json"
 	"encoding/pem"
 	"fmt"
 	"os"
@@ -74,6 +75,8 @@ type integrationTest struct {
 	nthRebalance bool
 	// enable GCE startup script
 	startupScript bool
+	// verify "kops get assets" functionality
+	testGetAssets bool
 }
 
 func newIntegrationTest(clusterName, srcDir string) *integrationTest {
@@ -88,6 +91,11 @@ func newIntegrationTest(clusterName, srcDir string) *integrationTest {
 	}
 }
 
+func (i *integrationTest) withTestGetAssets() *integrationTest {
+	i.testGetAssets = true
+	return i
+}
+
 func (i *integrationTest) withStartupScript() *integrationTest {
 	i.startupScript = true
 	return i
@@ -190,16 +198,6 @@ func (i integrationTest) withDefaultServiceAccountRoles24() *integrationTest {
 		withServiceAccountRole("ebs-csi-controller-sa.kube-system", true)
 }
 
-// withDefaultAddons24 adds the default addons for an AWS cluster running k8s 1.24
-func (i integrationTest) withDefaultAddons24() *integrationTest {
-	return i.withAddons(
-		awsCCMAddon,
-		awsEBSCSIAddon,
-		dnsControllerAddon,
-		leaderElectionAddon,
-	)
-}
-
 // withDefaultAddons30 adds the default addons for an AWS cluster running k8s 1.30
 func (i integrationTest) withDefaultAddons30() *integrationTest {
 	return i.withAddons(
@@ -210,7 +208,7 @@ func (i integrationTest) withDefaultAddons30() *integrationTest {
 }
 
 func (i integrationTest) withDefaults24() *integrationTest {
-	return i.withDefaultAddons24().withDefaultServiceAccountRoles24()
+	return i.withDefaultAddons30().withDefaultServiceAccountRoles24()
 }
 
 const (
@@ -228,11 +226,11 @@ const (
 	canalAddon   = "networking.projectcalico.org.canal-k8s-1.25"
 	ciliumAddon  = "networking.cilium.io-k8s-1.16"
 	flannelAddon = "networking.flannel-k8s-1.25"
+	kindnetAddon = "networking.kindnet-k8s-1.32"
 
 	certManagerAddon         = "certmanager.io-k8s-1.16"
 	clusterAutoscalerAddon   = "cluster-autoscaler.addons.k8s.io-k8s-1.15"
 	dnsControllerAddon       = "dns-controller.addons.k8s.io-k8s-1.12"
-	leaderElectionAddon      = "leader-migration.rbac.addons.k8s.io-k8s-1.23"
 	metricsServerAddon       = "metrics-server.addons.k8s.io-k8s-1.11"
 	nodeProblemDetectorAddon = "node-problem-detector.addons.k8s.io-k8s-1.17"
 )
@@ -248,35 +246,8 @@ func TestMinimalAWS(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
-// TestMinimal runs the test on a minimum configuration
-func TestMinimal_v1_25(t *testing.T) {
-	newIntegrationTest("minimal.example.com", "minimal-1.25").
-		withAddons(
-			awsEBSCSIAddon,
-			dnsControllerAddon,
-			awsCCMAddon,
-			leaderElectionAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
-// TestMinimal runs the test on a minimum configuration
-func TestMinimal_v1_26(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
-	newIntegrationTest("minimal.example.com", "minimal-1.26").
-		withAddons(
-			awsEBSCSIAddon,
-			dnsControllerAddon,
-			awsCCMAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
 // TestMinimal runs the test on a minimum configuration
 func TestMinimal_v1_27(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
 	newIntegrationTest("minimal.example.com", "minimal-1.27").
 		withAddons(
 			awsEBSCSIAddon,
@@ -288,8 +259,6 @@ func TestMinimal_v1_27(t *testing.T) {
 
 // TestMinimal runs the test on a minimum configuration
 func TestMinimal_v1_28(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
 	newIntegrationTest("minimal.example.com", "minimal-1.28").
 		withAddons(
 			awsEBSCSIAddon,
@@ -301,8 +270,6 @@ func TestMinimal_v1_28(t *testing.T) {
 
 // TestMinimal runs the test on a minimum configuration
 func TestMinimal_v1_29(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
 	newIntegrationTest("minimal.example.com", "minimal-1.29").
 		withAddons(
 			awsEBSCSIAddon,
@@ -314,8 +281,6 @@ func TestMinimal_v1_29(t *testing.T) {
 
 // TestMinimal runs the test on a minimum configuration
 func TestMinimal_v1_30(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
 	newIntegrationTest("minimal.example.com", "minimal-1.30").
 		withAddons(
 			awsEBSCSIAddon,
@@ -325,10 +290,30 @@ func TestMinimal_v1_30(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
+// TestMinimal runs the test on a minimum configuration
+func TestMinimal_v1_31(t *testing.T) {
+	newIntegrationTest("minimal.example.com", "minimal-1.31").
+		withAddons(
+			awsEBSCSIAddon,
+			dnsControllerAddon,
+			awsCCMAddon,
+		).
+		runTestTerraformAWS(t)
+}
+
+// TestMinimal runs the test on a minimum configuration
+func TestMinimal_v1_32(t *testing.T) {
+	newIntegrationTest("minimal.example.com", "minimal-1.32").
+		withAddons(
+			awsEBSCSIAddon,
+			dnsControllerAddon,
+			awsCCMAddon,
+		).
+		runTestTerraformAWS(t)
+}
+
 // TestMinimal_NoneDNS runs the test on a minimum configuration with --dns=none
 func TestMinimal_NoneDNS(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-
 	newIntegrationTest("minimal.example.com", "minimal-dns-none").
 		withAddons(
 			awsEBSCSIAddon,
@@ -538,14 +523,14 @@ func TestExternalPolicies(t *testing.T) {
 // TestMinimalIPv6 runs the test on a minimum IPv6 configuration
 func TestMinimalIPv6(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6").
-		withDefaultAddons24().
+		withDefaultAddons30().
 		runTestTerraformAWS(t)
 }
 
 // TestMinimalIPv6Calico runs the test on a minimum IPv6 configuration with Calico
 func TestMinimalIPv6Calico(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-calico").
-		withDefaultAddons24().
+		withDefaultAddons30().
 		withAddons(calicoAddon).
 		runTestTerraformAWS(t)
 }
@@ -553,7 +538,7 @@ func TestMinimalIPv6Calico(t *testing.T) {
 // TestMinimalIPv6Cilium runs the test on a minimum IPv6 configuration with Cilium
 func TestMinimalIPv6Cilium(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-cilium").
-		withDefaultAddons24().
+		withDefaultAddons30().
 		withAddons(ciliumAddon).
 		runTestTerraformAWS(t)
 }
@@ -561,7 +546,7 @@ func TestMinimalIPv6Cilium(t *testing.T) {
 // TestMinimalIPv6NoSubnetPrefix runs the test with "/64#N" subnet notation
 func TestMinimalIPv6NoSubnetPrefix(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-no-subnet-prefix").
-		withDefaultAddons24().
+		withDefaultAddons30().
 		runTestTerraformAWS(t)
 }
 
@@ -637,16 +622,33 @@ func TestBastionAdditionalUserData(t *testing.T) {
 func TestPrivateFlannel(t *testing.T) {
 	newIntegrationTest("privateflannel.example.com", "privateflannel").
 		withPrivate().
-		withDefaultAddons24().
+		withDefaultAddons30().
 		withAddons(flannelAddon).
 		runTestTerraformAWS(t)
 }
 
+// TestPrivateKindnet runs the test on a configuration with private topology, flannel networking
+func TestPrivateKindnet(t *testing.T) {
+	newIntegrationTest("privatekindnet.example.com", "privatekindnet").
+		withPrivate().
+		withDefaultAddons30().
+		withAddons(kindnetAddon).
+		runTestTerraformAWS(t)
+}
+
+// TestPrivateKindnet runs the test on a configuration with private topology, flannel networking
+func TestKindnetIPv6(t *testing.T) {
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-kindnet").
+		withDefaultAddons30().
+		withAddons(kindnetAddon).
+		runTestTerraformAWS(t)
+}
+
 // TestPrivateCalico runs the test on a configuration with private topology, calico networking
 func TestPrivateCalico(t *testing.T) {
 	newIntegrationTest("privatecalico.example.com", "privatecalico").
 		withPrivate().
-		withDefaultAddons24().
+		withDefaultAddons30().
 		withAddons(calicoAddon).
 		runTestTerraformAWS(t)
 }
@@ -702,7 +704,7 @@ func TestPrivateCiliumENI(t *testing.T) {
 func TestPrivateCanal(t *testing.T) {
 	newIntegrationTest("privatecanal.example.com", "privatecanal").
 		withPrivate().
-		withDefaultAddons24().
+		withDefaultAddons30().
 		withAddons(canalAddon).
 		runTestTerraformAWS(t)
 }
@@ -861,57 +863,7 @@ func TestManyAddonsCCMIRSA(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
-func TestManyAddonsCCMIRSA25(t *testing.T) {
-	newIntegrationTest("minimal.example.com", "many-addons-ccm-irsa25").
-		withOIDCDiscovery().
-		withServiceAccountRole("aws-load-balancer-controller.kube-system", true).
-		withServiceAccountRole("dns-controller.kube-system", true).
-		withServiceAccountRole("aws-cloud-controller-manager.kube-system", true).
-		withServiceAccountRole("cluster-autoscaler.kube-system", true).
-		withServiceAccountRole("ebs-csi-controller-sa.kube-system", true).
-		withServiceAccountRole("aws-node-termination-handler.kube-system", true).
-		withAddons(
-			"aws-load-balancer-controller.addons.k8s.io-k8s-1.19",
-			"aws-ebs-csi-driver.addons.k8s.io-k8s-1.17",
-			"certmanager.io-k8s-1.16",
-			"cluster-autoscaler.addons.k8s.io-k8s-1.15",
-			"networking.amazon-vpc-routed-eni-k8s-1.16",
-			"snapshot-controller.addons.k8s.io-k8s-1.20",
-			"aws-cloud-controller.addons.k8s.io-k8s-1.18",
-			leaderElectionAddon,
-			metricsServerAddon,
-			dnsControllerAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
-func TestManyAddonsCCMIRSA26(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
-	newIntegrationTest("minimal.example.com", "many-addons-ccm-irsa26").
-		withOIDCDiscovery().
-		withServiceAccountRole("aws-load-balancer-controller.kube-system", true).
-		withServiceAccountRole("dns-controller.kube-system", true).
-		withServiceAccountRole("aws-cloud-controller-manager.kube-system", true).
-		withServiceAccountRole("cluster-autoscaler.kube-system", true).
-		withServiceAccountRole("ebs-csi-controller-sa.kube-system", true).
-		withServiceAccountRole("aws-node-termination-handler.kube-system", true).
-		withAddons(
-			"aws-load-balancer-controller.addons.k8s.io-k8s-1.19",
-			"aws-ebs-csi-driver.addons.k8s.io-k8s-1.17",
-			"certmanager.io-k8s-1.16",
-			"cluster-autoscaler.addons.k8s.io-k8s-1.15",
-			"networking.amazon-vpc-routed-eni-k8s-1.16",
-			"snapshot-controller.addons.k8s.io-k8s-1.20",
-			"aws-cloud-controller.addons.k8s.io-k8s-1.18",
-			"nodelocaldns.addons.k8s.io-k8s-1.12",
-			metricsServerAddon,
-			dnsControllerAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
 func TestManyAddonsGCE(t *testing.T) {
-	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
 	newIntegrationTest("minimal.example.com", "many-addons-gce").
 		withAddons(
 			certManagerAddon,
@@ -1007,7 +959,7 @@ func TestSharedVPC(t *testing.T) {
 // TestSharedVPCIPv6 runs the test on a configuration with a shared VPC using IPv6
 func TestSharedVPCIPv6(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "shared_vpc_ipv6").
-		withDefaultAddons24().
+		withDefaultAddons30().
 		runTestTerraformAWS(t)
 }
 
@@ -1096,6 +1048,7 @@ func TestContainerd(t *testing.T) {
 			dnsControllerAddon,
 			awsCCMAddon,
 		).
+		withTestGetAssets().
 		runTestTerraformAWS(t)
 }
 
@@ -1259,10 +1212,19 @@ func (i *integrationTest) runTest(t *testing.T, ctx context.Context, h *testutil
 		options.ClusterName = i.clusterName
 		options.LifecycleOverrides = i.lifecycleOverrides
 
-		_, err := RunUpdateCluster(ctx, factory, &stdout, options)
+		updateClusterResults, err := RunUpdateCluster(ctx, factory, &stdout, options)
 		if err != nil {
 			t.Fatalf("error running update cluster %q: %v", i.clusterName, err)
 		}
+
+		// Verify that we can print all the tasks
+		// Catches bugs like https://github.com/kubernetes/kops/issues/17316
+		for key, task := range updateClusterResults.TaskMap {
+			if _, err := json.Marshal(task); err != nil {
+				t.Errorf("unable to marshal task %q of type %T to json: %v", key, task, err)
+			}
+		}
+
 	}
 
 	// Compare main files
@@ -1365,6 +1327,22 @@ func (i *integrationTest) runTest(t *testing.T, ctx context.Context, h *testutil
 			}
 		}
 	}
+
+	if i.testGetAssets {
+		options := &GetAssetsOptions{}
+		options.GetOptions = &GetOptions{}
+		options.Output = "yaml"
+		options.ClusterName = i.clusterName
+
+		var assetsOut bytes.Buffer
+		err := RunGetAssets(ctx, factory, &assetsOut, options)
+		if err != nil {
+			t.Fatalf("error running get assets %q: %v", i.clusterName, err)
+		}
+
+		wantPath := filepath.Join(i.srcDir, "assets.yaml")
+		golden.AssertMatchesFile(t, assetsOut.String(), wantPath)
+	}
 }
 
 func (i *integrationTest) setupCluster(t *testing.T, ctx context.Context, inputYAML string, stdout bytes.Buffer) *util.Factory {
@@ -1527,6 +1505,8 @@ func storeKeyset(t *testing.T, ctx context.Context, keyStore fi.Keystore, name s
 }
 
 func (i *integrationTest) runTestTerraformAWS(t *testing.T) {
+	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
+
 	ctx := testcontext.ForTest(t)
 	h := testutils.NewIntegrationTestHarness(t)
 	defer h.Close()
@@ -1615,6 +1595,8 @@ func (i *integrationTest) runTestTerraformAWS(t *testing.T) {
 }
 
 func (i *integrationTest) runTestPhase(t *testing.T, phase cloudup.Phase) {
+	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
+
 	ctx := testcontext.ForTest(t)
 	h := testutils.NewIntegrationTestHarness(t)
 	defer h.Close()
@@ -1660,6 +1642,8 @@ func (i *integrationTest) runTestPhase(t *testing.T, phase cloudup.Phase) {
 }
 
 func (i *integrationTest) runTestTerraformGCE(t *testing.T) {
+	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
+
 	ctx := testcontext.ForTest(t)
 	h := testutils.NewIntegrationTestHarness(t)
 	defer h.Close()
@@ -1688,8 +1672,8 @@ func (i *integrationTest) runTestTerraformGCE(t *testing.T) {
 		"aws_s3_object_"+i.clusterName+"-addons-kops-controller.addons.k8s.io-k8s-1.16_content",
 		"aws_s3_object_"+i.clusterName+"-addons-kubelet-api.rbac.addons.k8s.io-k8s-1.9_content",
 		"aws_s3_object_"+i.clusterName+"-addons-limit-range.addons.k8s.io_content",
-		"aws_s3_object_"+i.clusterName+"-addons-metadata-proxy.addons.k8s.io-v0.1.12_content",
-		"aws_s3_object_"+i.clusterName+"-addons-storage-gce.addons.k8s.io-v1.7.0_content")
+		"aws_s3_object_"+i.clusterName+"-addons-storage-gce.addons.k8s.io-v1.7.0_content",
+	)
 
 	for j := 0; j < i.zones; j++ {
 		zone := "us-test1-" + string([]byte{byte('a') + byte(j)})
@@ -1710,6 +1694,8 @@ func (i *integrationTest) runTestTerraformGCE(t *testing.T) {
 }
 
 func (i *integrationTest) runTestTerraformHetzner(t *testing.T) {
+	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
+
 	ctx := testcontext.ForTest(t)
 	h := testutils.NewIntegrationTestHarness(t)
 	defer h.Close()
@@ -1743,6 +1729,8 @@ func (i *integrationTest) runTestTerraformHetzner(t *testing.T) {
 }
 
 func (i *integrationTest) runTestTerraformScaleway(t *testing.T) {
+	t.Setenv("KOPS_RUN_TOO_NEW_VERSION", "1")
+
 	featureflag.ParseFlags("+Scaleway")
 	unsetFeatureFlags := func() {
 		featureflag.ParseFlags("-Scaleway")
