@@ -293,6 +293,14 @@ const (
 	CloudProviderOpenstack CloudProviderID = "openstack"
 	CloudProviderAzure     CloudProviderID = "azure"
 	CloudProviderScaleway  CloudProviderID = "scaleway"
+
+	// Experimental cloud providers
+	CloudProviderMetal CloudProviderID = "metal"
+
+	// If you add any cloud providers here, you must add them to:
+	// * Convert_kops_ClusterSpec_To_v1alpha2_ClusterSpec
+	// * cluster.GetCloudProvider()
+	// * type CloudProviderSpec
 )
 
 // FindImage returns the image for the cloudprovider, or nil if none found
@@ -358,13 +366,16 @@ func RecommendedKubernetesVersion(c *Channel, kopsVersionString string) *semver.
 // Returns true if the given image name has the stable or alpha channel images prefix. Otherwise false.
 func (c *Channel) HasUpstreamImagePrefix(image string) bool {
 	return strings.HasPrefix(image, "kope.io/k8s-") ||
+		strings.HasPrefix(image, "099720109477/ubuntu/images/hvm-ssd-gp3/ubuntu-noble-24.04-") ||
 		strings.HasPrefix(image, "099720109477/ubuntu/images/hvm-ssd/ubuntu-jammy-22.04-") ||
 		strings.HasPrefix(image, "099720109477/ubuntu/images/hvm-ssd/ubuntu-focal-20.04-") ||
 		strings.HasPrefix(image, "cos-cloud/cos-stable-") ||
 		strings.HasPrefix(image, "ubuntu-os-cloud/ubuntu-2004-focal-") ||
 		strings.HasPrefix(image, "ubuntu-os-cloud/ubuntu-2204-jammy-") ||
+		strings.HasPrefix(image, "ubuntu-os-cloud/ubuntu-2404-noble-") ||
 		strings.HasPrefix(image, "Canonical:0001-com-ubuntu-server-focal:20_04-lts-gen2:") ||
-		strings.HasPrefix(image, "Canonical:0001-com-ubuntu-server-jammy:22_04-lts-gen2:")
+		strings.HasPrefix(image, "Canonical:0001-com-ubuntu-server-jammy:22_04-lts-gen2:") ||
+		strings.HasPrefix(image, "Canonical:ubuntu-24_04-lts:server-gen1:")
 }
 
 // GetPackageVersion returns the version for the package, or an error if could not be found.
