@@ -29,13 +29,13 @@ type AWSCloudControllerManagerOptionsBuilder struct {
 	*OptionsContext
 }
 
-var _ loader.OptionsBuilder = &AWSCloudControllerManagerOptionsBuilder{}
+var _ loader.ClusterOptionsBuilder = &AWSCloudControllerManagerOptionsBuilder{}
 
 // BuildOptions generates the configurations used for the AWS cloud controller manager manifest
-func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) error {
-	clusterSpec := o.(*kops.ClusterSpec)
+func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(cluster *kops.Cluster) error {
+	clusterSpec := &cluster.Spec
 
-	if clusterSpec.GetCloudProvider() != kops.CloudProviderAWS {
+	if cluster.GetCloudProvider() != kops.CloudProviderAWS {
 		return nil
 	}
 
@@ -74,27 +74,21 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 
 	if eccm.Image == "" {
 		// See https://us.gcr.io/k8s-artifacts-prod/provider-aws/cloud-controller-manager
-		switch b.KubernetesVersion.Minor {
-		case 25:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.25.15"
-		case 26:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.11"
+		switch b.ControlPlaneKubernetesVersion().Minor() {
 		case 27:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.27.6"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.27.9"
 		case 28:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.5"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.9"
 		case 29:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.29.2"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.29.6"
 		case 30:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.30.0"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.30.3"
+		case 31:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.31.0"
 		default:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.30.0"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.31.0"
 		}
 	}
 
-	if b.IsKubernetesLT("1.25") {
-		eccm.EnableLeaderMigration = fi.PtrTo(true)
-	}
-
 	return nil
 }
