@@ -17,9 +17,10 @@ limitations under the License.
 package openstack
 
 import (
+	"context"
 	"fmt"
 
-	"github.com/gophercloud/gophercloud/openstack/networking/v2/subnets"
+	"github.com/gophercloud/gophercloud/v2/openstack/networking/v2/subnets"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/util/pkg/vfs"
@@ -33,7 +34,7 @@ func listSubnets(c OpenstackCloud, opt subnets.ListOptsBuilder) ([]subnets.Subne
 	var s []subnets.Subnet
 
 	done, err := vfs.RetryWithBackoff(readBackoff, func() (bool, error) {
-		allPages, err := subnets.List(c.NetworkingClient(), opt).AllPages()
+		allPages, err := subnets.List(c.NetworkingClient(), opt).AllPages(context.TODO())
 		if err != nil {
 			return false, fmt.Errorf("error listing subnets: %v", err)
 		}
@@ -61,7 +62,7 @@ func (c *openstackCloud) GetSubnet(subnetID string) (*subnets.Subnet, error) {
 func getSubnet(c OpenstackCloud, subnetID string) (*subnets.Subnet, error) {
 	var subnet *subnets.Subnet
 	done, err := vfs.RetryWithBackoff(readBackoff, func() (bool, error) {
-		sub, err := subnets.Get(c.NetworkingClient(), subnetID).Extract()
+		sub, err := subnets.Get(context.TODO(), c.NetworkingClient(), subnetID).Extract()
 		if err != nil {
 			return false, fmt.Errorf("error retrieving subnet: %v", err)
 		}
@@ -85,7 +86,7 @@ func createSubnet(c OpenstackCloud, opt subnets.CreateOptsBuilder) (*subnets.Sub
 	var s *subnets.Subnet
 
 	done, err := vfs.RetryWithBackoff(writeBackoff, func() (bool, error) {
-		v, err := subnets.Create(c.NetworkingClient(), opt).Extract()
+		v, err := subnets.Create(context.TODO(), c.NetworkingClient(), opt).Extract()
 		if err != nil {
 			return false, fmt.Errorf("error creating subnet: %v", err)
 		}
@@ -107,7 +108,7 @@ func (c *openstackCloud) DeleteSubnet(subnetID string) error {
 
 func deleteSubnet(c OpenstackCloud, subnetID string) error {
 	done, err := vfs.RetryWithBackoff(deleteBackoff, func() (bool, error) {
-		err := subnets.Delete(c.NetworkingClient(), subnetID).ExtractErr()
+		err := subnets.Delete(context.TODO(), c.NetworkingClient(), subnetID).ExtractErr()
 		if err != nil && !isNotFound(err) {
 			return false, fmt.Errorf("error deleting subnet: %v", err)
 		}
