@@ -322,6 +322,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	loader.Builders = append(loader.Builders, &networking.CommonBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.CalicoBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.CiliumBuilder{NodeupModelContext: modelContext})
+	loader.Builders = append(loader.Builders, &networking.KindnetBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.AmazonVPCRoutedENIBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.KuberouterBuilder{NodeupModelContext: modelContext})
 
@@ -348,7 +349,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 			Cloud:    cloud,
 		}
 	case "dryrun":
-		assetBuilder := assets.NewAssetBuilder(vfs.Context, nil, nodeupConfig.KubernetesVersion, false)
+		assetBuilder := assets.NewAssetBuilder(vfs.Context, nil, false)
 		target = fi.NewNodeupDryRunTarget(assetBuilder, out)
 	default:
 		return fmt.Errorf("unsupported target type %q", c.Target)
@@ -559,12 +560,20 @@ func modprobe(module string) error {
 }
 
 // loadKernelModules is a hack to force br_netfilter to be loaded
+// and used by some components to load its recommended modules.
 // TODO: Move to tasks architecture
 func loadKernelModules(context *model.NodeupModelContext) error {
-	err := modprobe("br_netfilter")
-	if err != nil {
-		// TODO: Return error in 1.11 (too risky for 1.10)
-		klog.Warningf("error loading br_netfilter module: %v", err)
+	if context.NodeupConfig.Networking.Kindnet != nil {
+		err := modprobe("nfnetlink_queue")
+		if err != nil {
+			klog.Warningf("error loading nfnetlink_queue module: %v", err)
+		}
+	} else {
+		err := modprobe("br_netfilter")
+		if err != nil {
+			// TODO: Return error in 1.11 (too risky for 1.10)
+			klog.Warningf("error loading br_netfilter module: %v", err)
+		}
 	}
 	// TODO: Add to /etc/modules-load.d/ ?
 	return nil
